@@ -40,3 +40,13 @@ class Line(Polygon):
 
     def __init__(self, x0, y0, x1, y1, color):
         super().__init__([(x0, y0), (x1, y1)], outline=color)
+
+    @property
+    def color(self):
+        """The line color value. Can be a hex value for a color or
+        ``None`` for no line color."""
+        return self.outline
+
+    @color.setter
+    def color(self, color):
+        self.outline = color
